@@ -7,6 +7,7 @@ from _screenshot import _ScreenshotKeywords
 from _applicationmanagement import _ApplicationManagementKeywords
 from _waiting import _WaitingKeywords
 from _touch import _TouchKeywords
+from _keyevent import _KeyeventKeywords
 
 __all__ = ["_LoggingKeywords",
            "_RunOnFailureKeywords",
@@ -15,4 +16,5 @@ __all__ = ["_LoggingKeywords",
            "_ApplicationManagementKeywords",
            "_WaitingKeywords",
            "_TouchKeywords",
+           "_KeyeventKeywords",
           ]
