@@ -49,7 +49,7 @@ class _ElementKeywords(KeywordGroup):
     def reset_application(self):
         """ Reset application """
         driver = self._current_application()
-        driver.execute_script('mobile: reset')
+        driver.reset()
 
     def hide_keyboard(self):
         """
@@ -62,7 +62,6 @@ class _ElementKeywords(KeywordGroup):
         driver = self._current_application()
         driver.hide_keyboard()
 
-
     def page_should_contain_text(self, text, loglevel='INFO'):
         """Verifies that current page contains `text`.
 
